@@ -47,6 +47,7 @@
 #include <QtGui/QResizeEvent>
 #include <QtGui/QMouseEvent>
 #include <QtGui/QDragEnterEvent>
+#include <QtGui/QToolTip>
 
 #include <cmath>         //::segmentAt()
 
@@ -141,23 +142,39 @@ void RadialMap::Widget::mouseMoveEvent(QMouseEvent *e)
 
     m_focus = segmentAt(p); //NOTE p is passed by non-const reference
 
-    if (m_focus && m_focus->file() != m_tree)
+    if (m_focus)
     {
         if (m_focus != oldFocus) //if not same as last time
         {
             setCursor(Qt::PointingHandCursor);
 
-            m_tip->updateTip(m_focus->file(), m_tree);
+            QString string = m_focus->file()->fullPath(m_tree)
+                + QLatin1Char('\n')
+                + m_focus->file()->humanReadableSize()
+                + QLatin1Char('\n');
+                
+            if (m_focus->file()->isFolder()) {
+                int files = static_cast<const Folder*>(m_focus->file())->children();
+                const uint percent = uint((100 * files) / (double)m_tree->children());
+                string += i18np("File: %1", "Files: %1", files);
+                
+                if (percent > 0) string += QString(QLatin1String( " (%1%)" )).arg(KGlobal::locale()->formatNumber(percent, 0));
+            }
+            
+            const KUrl url   = Widget::url(m_focus->file());
+            if (m_focus == m_rootSegment && url != url.upUrl()) {
+                string += i18n("\nClick to go up to parent directory");
+            }
+            
+            QToolTip::showText(e->globalPos(), string, this);
 
             emit mouseHover(m_focus->file()->fullPath());
             update();
         }
-        m_tip->moveTo(e->globalPos(), (p.y() < 0));
     }
     else if (oldFocus && oldFocus->file() != m_tree)
     {
         unsetCursor();
-        m_tip->hide();
         update();
 
         emit mouseHover(QString());
@@ -175,7 +192,9 @@ void RadialMap::Widget::enterEvent(QEvent *)
 
 void RadialMap::Widget::mousePressEvent(QMouseEvent *e)
 {
-    //m_tip is hidden already by event filter
+    if (!isEnabled())
+        return;
+    
     //m_focus is set correctly (I've been strict, I assure you it is correct!)
 
     if (m_focus && !m_focus->isFake())
@@ -245,6 +264,7 @@ void RadialMap::Widget::mousePressEvent(QMouseEvent *e)
                     job->ui()->setWindow(this);
                     connect(job, SIGNAL(finished(KJob*)), this, SLOT(deleteJobFinished(KJob*)));
                     QApplication::setOverrideCursor(Qt::BusyCursor);
+                    setEnabled(false);
                 }
             } else {
                 //ensure m_focus is set for new mouse position
@@ -256,8 +276,6 @@ void RadialMap::Widget::mousePressEvent(QMouseEvent *e)
 section_two:
             const QRect rect(e->x() - 20, e->y() - 20, 40, 40);
 
-            m_tip->hide(); // user expects this
-
             if (!isDir || e->button() == Qt::MidButton) {
                 // KIconEffect::visualActivate(this, rect); // TODO: recreate this
                 new KRun(url, this, true); //FIXME see above
@@ -267,7 +285,7 @@ section_two:
                 emit activated(url); //activate first, this will cause UI to prepare itself
                 createFromCache((Folder *)m_focus->file());
             }
-            else
+            else if (url.upUrl() != url)
                 emit giveMeTreeFor(url.upUrl());
         }
     }
@@ -276,15 +294,14 @@ section_two:
 void RadialMap::Widget::deleteJobFinished(KJob *job)
 {
     QApplication::restoreOverrideCursor();
+    setEnabled(true);
     if (!job->error() && m_toBeDeleted) {
         m_toBeDeleted->file()->parent()->remove(m_toBeDeleted->file());
         delete m_toBeDeleted->file();
+        m_toBeDeleted = 0;
         m_focus = 0;
         m_map.make(m_tree, true);
         repaint();
-
-        //delete m_toBeDeleted->file(); // TODO: this seems to be cleaned up elsewhere? Make sure of it.
-        m_toBeDeleted = 0;
     } else
         KMessageBox::error(this, job->errorString(), i18n("Error while deleting"));
 }
